"""Exponential decay fitting utilities."""

from .exp_decay import FitResult, fit_linc_domain, fit_lin0_domain, fit_log_domain

__all__ = [
    "FitResult",
    "fit_linc_domain",
    "fit_lin0_domain",
    "fit_log_domain",
]
